Learn R Programming

BRAIN (version 1.18.0)

BRAIN-package: Implementation of BRAIN (Baffling Recursive Algorithm for Isotope distributioN calculations)

Description

This package implements BRAIN (Baffling Recursive Algorithm for Isotope distributioN calculations) is described in full details by Claesen et al. The algorithm uses an algebraic approach (Viete's formulas, Newton identities [Macd]) which is especially useful for large molecules due to its advantageous scaling properties. This version of the package provides functions for calculating the aggregated isotopic distribution and center-masses masses for each aggregated isotopic variant for chemical components built from carbon, hydrogen, oxygen, nitrogen and sulfur (e.g. peptides). The natural abundances and molecular masses for stable isotopes of C, H, N, O, S are taken from IUPAC 1997 [Rosm].

Arguments

Details

Package:
BRAIN
Type:
Package
Version:
1.4.0
Date:
2013-01-18
License:
GPL-2
LazyLoad:
yes

References

[Clae] Claesen J., Dittwald P., Burzykowski T. and Valkenborg D. An efficient method to calculate the aggregated isotopic distribution and exact center-masses. JASMS, 2012, doi:10.1007/s13361-011-0326-2

[Macd] Macdonald I.G., Symmetric functions and Hall polynomials / by I. G. Macdonald. Clarendon Press; Oxford University Press, Oxford : New York, 1979.

[Rosm] K.J.R. Rosman and P.D.P. Taylor. Isotopic compositions of the elements 1997. Pure and Applied Chemistry, 70(1):217-235, 1998.

Examples

Run this code
  nrPeaks = 1000
  aC <-  list(C=23832, H=37816, N=6528, O=7031, S=170)  # Human dynein heavy chain  
  res <- useBRAIN(aC = aC, nrPeaks = nrPeaks)
  iso <- res$isoDistr
  masses <- res$masses
  mono <- res$monoisotopicMass
  avgMass <- res$avgMass

Run the code above in your browser using DataLab