Learn R Programming

BRAIN (version 1.18.0)

calculateAverageMass: Function computing theoretical average masses.

Description

Function computing the theoretical average masses for chemical components composed of carbon, hydrogen, oxygen, nitrogen and sulfur (e.g. peptides).

Usage

calculateAverageMass(aC)

Arguments

aC
List with fields C, H, N, O, S of integer non-negative values (if any field is ommited, then its value is set to 0).

Value

Average mass (numeric)

Details

Mass is calculated in Daltons.

References

[Clae] Claesen J., Dittwald P., Burzykowski T. and Valkenborg D. An efficient method to calculate the aggregated isotopic distribution and exact center-masses. JASMS, 2012, doi:10.1007/s13361-011-0326-2

See Also

useBRAIN

Examples

Run this code
  aC <-  list(C=23832, H=37816, N=6528, O=7031, S=170)  # Human dynein heavy chain
  res <- calculateAverageMass(aC = aC)

Run the code above in your browser using DataLab