Learn R Programming

BRAIN (version 1.18.0)

useBRAIN: Function computing probabilities of aggregated isotopic variants and their center-masses using BRAIN algorithm.

Description

Function computing probabilities of isotopic variants and their aggregated masses for chemical components composed of carbon, hydrogen, oxygen, nitrogen and sulfur (e.g. peptides). Additionally the function returns also the monoisotopic mass and the average mass of given chemical component.

Usage

useBRAIN(aC, stopOption = "nrPeaks", nrPeaks, coverage, abundantEstim)

Arguments

aC
List with fields C, H, N, O, S of integer non-negative values (if any field is ommited, then its value is set to 0).
stopOption
one of the following strings: "nrPeaks" (default), "coverage", "abundantEstim"
nrPeaks
Integer indicating the number of consecutive isotopic variants to be calculated, starting from the monoisotopic one. This value can always be provided, even if is not a default setting. In the latter case it is a hard stopping criterion.
coverage
Scalar indicating the value of the cumulative aggregated distribution. The calculations will be stopped after reaching this value.
abundantEstim
Integer indicating the number of consecutive isotopic variants to be calculated, starting from one after the most abundant one. All consecutive isotopic variants before the most abundant peak are also returned.

Value

Named list with the following fields:
  • isoDistrProbabilities of aggregated isotopic variants (numeric vector)
  • massesAggregated masses for isotopic variants (numeric vector)
  • monoisotopicMassMonoisotopic mass (numeric)
  • avgMassAverage mass - weighted average of the isotopic variants contributing to the most abundant aggregated variant (numeric)

Details

Function uses recursive formulae based on algebraic Newton-Girard identity (see [Clae]).

References

[Clae] Claesen J., Dittwald P., Burzykowski T. and Valkenborg D. An efficient method to calculate the aggregated isotopic distribution and exact center-masses. JASMS, 2012, doi:10.1007/s13361-011-0326-2

See Also

calculateIsotopicProbabilities

Examples

Run this code
  nrPeaks = 1000  
  aC <-  list(C=23832, H=37816, N=6528, O=7031, S=170)  # Human dynein heavy chain  
  res <-  useBRAIN(aC = aC, stopOption="nrPeaks", nrPeaks = nrPeaks)

Run the code above in your browser using DataLab