getAtomsFromSeq:
Function computing an atomic composition from amono acid sequence.
Description
Function computing an atomic composition from (naturally occuring) amino acid sequence.
Usage
getAtomsFromSeq(seq)
Arguments
seq
The character vector of AAString (see Biostrings package) with amino acid sequence. It should contain only letters "A", "R", "N", "D", "C", "E", "Q", "G", "H", "I", "L", "K", "M", "F", "P", "S", "T", "W", "Y", "V" (1-letter symbols of 20 naturally occuring amino acids).
Value
Named list with the following fields with number of correcponding atoms (integer non-negative values):
C,
H,
N,
O,
S
Details
The atomic composition is just a summaric atomic composition of
all amino acids composing the sequence minus (n-1) times the water molecule, where n is a length of given amino acid sequence.